@@ -31,3 +31,7 @@ class CountGenerator(IAsyncCountGenerator):
         if is_validators.is_int(maxsize):
             minsize = abs(maxsize)
         return range(minsize)
+
+
+    def __str__(self):
+        return f"{self.__class__.__name__}(count={self._maxsize}, speed={self._speed})"
\ No newline at end of file
