@@ -21,11 +21,9 @@ class Speed(Awaitable, IAwaitSpeed):
     speed module
     """
 
-    def __init__(self,
-                 speed: SpeedTypes,
-                 unit: SpeedUnit = UnitOfTime.MICROSECOND):
+    def __init__(self, speed: SpeedTypes, unit: SpeedUnit = UnitOfTime.MICROSECOND):
         self._speed = speed
-        self._unit = timeunit(unit)
+        self._unit = unit
 
     def __await__(self):
         return self._await_speed(self.computed_speed_use_lru()).__await__()
@@ -35,4 +33,7 @@ class Speed(Awaitable, IAwaitSpeed):
 
     @lru_cache()
     def computed_speed_use_lru(self):
-        return self._speed / self._unit
+        return self._speed / timeunit(self._unit)
+
+    def __str__(self):
+        return f"{self.__class__.__name__}(speed={self.computed_speed_use_lru()})"
