@@ -50,12 +50,6 @@ class IWorkerMaster(object):
         raise NotImplementedError("NotImplemented .start() -> T")
 
 
-class IBuilder(object):
-
-    def build(self) -> T:
-        raise NotImplementedError("NotImplemented .build() -> T")
-
-
 class IFactory(object):
 
     @classmethod
