@@ -86,3 +86,7 @@ class EmitWorkerGroup(IWorkerGroup):
 
     def _is_worker(self, value):
         return isinstance(value, IWorker)
+
+
+    def __str__(self):
+        return f"{self.__class__.__name__}(workers={len(self.buffer)})"
\ No newline at end of file
